==> jc-1.4.0.tar.gz: java/security/UnresolvedPermissionCollection__241.h <==
// final class java.security.UnresolvedPermissionCollection$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 92190d6dd241e6fb java_security_UnresolvedPermissionCollection__241

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_UnresolvedPermissionCollection__241_H_
#define _JC_java_security_UnresolvedPermissionCollection__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_UnresolvedPermissionCollection$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_java_security_UnresolvedPermissionCollection__241$sub_refs	_jc_java_security_UnresolvedPermissionCollection__241$sub_refs;
typedef struct _jc_java_security_UnresolvedPermissionCollection__241$sub_nonrefs	_jc_java_security_UnresolvedPermissionCollection__241$sub_nonrefs;
typedef struct _jc_java_security_UnresolvedPermissionCollection__241$refs	_jc_java_security_UnresolvedPermissionCollection__241$refs;
typedef struct _jc_java_security_UnresolvedPermissionCollection__241$nonrefs	_jc_java_security_UnresolvedPermissionCollection__241$nonrefs;
typedef struct _jc_java_security_UnresolvedPermissionCollection__241$object	_jc_java_security_UnresolvedPermissionCollection__241$object;

typedef const struct _jc_java_security_UnresolvedPermissionCollection__241$vmethods	_jc_java_security_UnresolvedPermissionCollection__241$vmethods;
typedef const struct _jc_java_security_UnresolvedPermissionCollection__241$vtable	_jc_java_security_UnresolvedPermissionCollection__241$vtable;
typedef const struct _jc_java_security_UnresolvedPermissionCollection__241$vtype	_jc_java_security_UnresolvedPermissionCollection__241$vtype;

// Constructors
extern void _jc_java_security_UnresolvedPermissionCollection__241$method$_init$c1474fb1abeefcd4(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *, struct _jc_java_security_UnresolvedPermissionCollection$object *);

// Virtual methods
extern jboolean _jc_java_security_UnresolvedPermissionCollection__241$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *);
extern struct _jc_java_lang_Object$object *_jc_java_security_UnresolvedPermissionCollection__241$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *);
extern void _jc_java_security_UnresolvedPermissionCollection__241$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_UnresolvedPermissionCollection__241$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_java_security_UnresolvedPermissionCollection__241$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_java_security_UnresolvedPermissionCollection__241$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_UnresolvedPermissionCollection__241$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *);
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *);
};

// Vtable
struct _jc_java_security_UnresolvedPermissionCollection__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_UnresolvedPermissionCollection__241$vmethods	java_security_UnresolvedPermissionCollection__241;
};

// Vtype
struct _jc_java_security_UnresolvedPermissionCollection__241$vtype {
	_jc_type			type;
	_jc_java_security_UnresolvedPermissionCollection__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_UnresolvedPermissionCollection__241$sub_refs {
	struct _jc_object	*main__5fenum;
	struct _jc_object	*sub__5fenum;
	struct _jc_java_security_UnresolvedPermissionCollection$object	*this;
};

// Reference instance fields (object)
struct _jc_java_security_UnresolvedPermissionCollection__241$refs {
    _jc_java_security_UnresolvedPermissionCollection__241$sub_refs	java_security_UnresolvedPermissionCollection__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_UnresolvedPermissionCollection__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_UnresolvedPermissionCollection__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_UnresolvedPermissionCollection__241$sub_nonrefs	java_security_UnresolvedPermissionCollection__241;
};

// Object instance structure
struct _jc_java_security_UnresolvedPermissionCollection__241$object {
	_jc_java_security_UnresolvedPermissionCollection__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_UnresolvedPermissionCollection__241$vtype	*vtype;
	_jc_java_security_UnresolvedPermissionCollection__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_UnresolvedPermissionCollection__241$vtype _jc_java_security_UnresolvedPermissionCollection__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_UnresolvedPermissionCollection__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_UnresolvedPermissionCollection__241$class_object;

#endif	/* _JC_java_security_UnresolvedPermissionCollection__241_H_ */

==> jc-1.4.6.tar.gz: java/security/UnresolvedPermissionCollection__241.h <==
// final class java.security.UnresolvedPermissionCollection$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 92190d6dd241e6fb java_security_UnresolvedPermissionCollection__241

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_UnresolvedPermissionCollection__241_H_
#define _JC_java_security_UnresolvedPermissionCollection__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_UnresolvedPermissionCollection$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_java_security_UnresolvedPermissionCollection__241$sub_refs	_jc_java_security_UnresolvedPermissionCollection__241$sub_refs;
typedef struct _jc_java_security_UnresolvedPermissionCollection__241$sub_nonrefs	_jc_java_security_UnresolvedPermissionCollection__241$sub_nonrefs;
typedef struct _jc_java_security_UnresolvedPermissionCollection__241$refs	_jc_java_security_UnresolvedPermissionCollection__241$refs;
typedef struct _jc_java_security_UnresolvedPermissionCollection__241$nonrefs	_jc_java_security_UnresolvedPermissionCollection__241$nonrefs;
typedef struct _jc_java_security_UnresolvedPermissionCollection__241$object	_jc_java_security_UnresolvedPermissionCollection__241$object;

typedef const struct _jc_java_security_UnresolvedPermissionCollection__241$vmethods	_jc_java_security_UnresolvedPermissionCollection__241$vmethods;
typedef const struct _jc_java_security_UnresolvedPermissionCollection__241$vtable	_jc_java_security_UnresolvedPermissionCollection__241$vtable;
typedef const struct _jc_java_security_UnresolvedPermissionCollection__241$vtype	_jc_java_security_UnresolvedPermissionCollection__241$vtype;

// Constructors
extern void _jc_java_security_UnresolvedPermissionCollection__241$method$_init$c1474fb1abeefcd4(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *, struct _jc_java_security_UnresolvedPermissionCollection$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_security_UnresolvedPermissionCollection__241$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_security_UnresolvedPermissionCollection__241$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_UnresolvedPermissionCollection__241$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_UnresolvedPermissionCollection__241$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_java_security_UnresolvedPermissionCollection__241$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_java_security_UnresolvedPermissionCollection__241$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_UnresolvedPermissionCollection__241$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_UnresolvedPermissionCollection__241$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_UnresolvedPermissionCollection__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_UnresolvedPermissionCollection__241$vmethods	java_security_UnresolvedPermissionCollection__241;
};

// Vtype
struct _jc_java_security_UnresolvedPermissionCollection__241$vtype {
	_jc_type			type;
	_jc_java_security_UnresolvedPermissionCollection__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_UnresolvedPermissionCollection__241$sub_refs {
	struct _jc_object	*main__5fenum;
	struct _jc_object	*sub__5fenum;
	struct _jc_java_security_UnresolvedPermissionCollection$object	*this;
};

// Reference instance fields (object)
struct _jc_java_security_UnresolvedPermissionCollection__241$refs {
    _jc_java_security_UnresolvedPermissionCollection__241$sub_refs	java_security_UnresolvedPermissionCollection__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_UnresolvedPermissionCollection__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_UnresolvedPermissionCollection__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_UnresolvedPermissionCollection__241$sub_nonrefs	java_security_UnresolvedPermissionCollection__241;
};

// Object instance structure
struct _jc_java_security_UnresolvedPermissionCollection__241$object {
	_jc_java_security_UnresolvedPermissionCollection__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_UnresolvedPermissionCollection__241$vtype	*vtype;
	_jc_java_security_UnresolvedPermissionCollection__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_UnresolvedPermissionCollection__241$vtype _jc_java_security_UnresolvedPermissionCollection__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_UnresolvedPermissionCollection__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_UnresolvedPermissionCollection__241$class_object;

#endif	/* _JC_java_security_UnresolvedPermissionCollection__241_H_ */
